@@ -1,6 +1,8 @@
 if (getRversion() >= "2.15.1") {
   utils::globalVariables(
     c(
+      'lon',
+      'lat',
       'storm_columns',
       'storm_names',
       'value',
