@@ -2,8 +2,7 @@ context("buoy")
 
 test_that("buoys works", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
 
   vcr::use_cassette("buoys", {
     aa <- buoys(dataset = 'cwind')
@@ -19,16 +18,14 @@ test_that("buoys works", {
 
 test_that("buoys fails well", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
 
   expect_error(buoys(), "argument \"dataset\" is missing")
 })
 
 test_that("buoy works", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
 
   vcr::use_cassette("buoy_disk", {
     one <- buoy(dataset = 'cwind', buoyid = 41001, year = 1997, datatype = "c")
@@ -46,8 +43,7 @@ test_that("buoy works", {
 
 test_that("buoy works with character buoy ids", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
 
   vcr::use_cassette("buoy_buoyid_param", {
     aa <- buoy(dataset = "stdmet", buoyid = "wplf1")
@@ -62,8 +58,7 @@ test_that("buoy works with character buoy ids", {
 
 test_that("buoy works regardless of buoyid case", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
 
   vcr::use_cassette("buoy_buoyid_case", {
     aa <- buoy(dataset = "stdmet", buoyid = "vcaf1")
@@ -75,8 +70,7 @@ test_that("buoy works regardless of buoyid case", {
 
 test_that("buoys fails well", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
 
   expect_error(buoy(), "argument \"dataset\" is missing")
 
@@ -90,8 +84,7 @@ test_that("buoys fails well", {
 
 test_that("buoy works as expected with buoy id's without lat/lon data", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
 
   vcr::use_cassette("buoy_buoyid_no_latlon", {
     nn <- suppressWarnings(buoy(dataset='adcp2', buoyid=46081))
