@@ -25,3 +25,22 @@ test_that("ncdc_stations returns the correct...", {
     expect_equal(NCOL(cc$data), 9)
   })
 })
+
+# no internet required
+test_that("ncdc_stations fails well", {
+  skip_on_cran()
+
+  # unload vcr namespace
+  unloadNamespace("vcr")
+
+  webmockr::enable()
+  url <- 'https://www.ncdc.noaa.gov/cdo-web/api/v2/stations/COOP:010008'
+  ss <- webmockr::stub_request('get', url)
+  webmockr::to_return(ss, body = "<!DOCTYPE HTML PUBLIC><>")
+  expect_error(ncdc_stations(stationid='COOP:010008'), "lexical error")
+  webmockr::disable()
+
+  # re-attach vcr namespace
+  attachNamespace("vcr")
+  vcr_set()
+})
